﻿--Bar creation module

local width, height = 300, 24

function SN:CreateBar(group, cooldown, duration, caster, guid, spell)

	--Make our lives easier with some variables
	local v = SN.Media
	local class, classFileName, classID = UnitClass(caster)
	local bar

	--Start the CD Timer
	--Check to see if ElvUI is on so we can make the frames match
	if (IsAddOnLoaded("ElvUI")) then
		if group == SN.F.debuffs then
			bar = SN.timers:NewBar(nil, width, height - 4, v.media.minTex)
		else
			bar = SN.timers:NewBar(nil, width, height, v.media.minTex)
		end
		SN:SNCreateBG(bar)
	else
		if group == SN.F.debuffs then
			bar = SN.timers:NewBar(nil, width, height, v.media.minTex)
		else
			bar = SN.timers:NewBar(nil, width, height + 8, v.media.minTex)
		end

		--Standard Backdrop settings
		bar:SetAlpha(1)
		bar:SetBackdrop({
			bgFile = v.media.blankTex, 
			edgeFile = v.media.blankTex, 
			tile = false, tileSize = 0, edgeSize = 2, 
			insets = { left = -2, right = 2, top = 2, bottom = -2 }
		})
		bar:SetBackdropColor(0, 0, 0, 0)
		bar:SetBackdropBorderColor(0.1, 0.1, 0.1, 1)
	end
	
	--Setup the data keys that the bar will hold
	bar:SetData("SN:arg1", group)
	bar:SetData("SN:arg2", cooldown)
	bar:SetData("SN:arg3", guid)
	bar:SetData("SN:arg4", caster)
	bar:SetData("SN:arg5", spell)
	bar:SetData("SN:arg6", classID)

	--Grab the player's class color and the icon of the spell
	local colortmp = RAID_CLASS_COLORS[classFileName]
	color = { colortmp.r, colortmp.g, colortmp.b }
	local _, _, icon = GetSpellInfo(cooldown.id)
	bar:SetIcon(icon)
	
	bar:SetColor(color)
	bar:SetDuration(duration)
	bar:SetLabelFont(v.media.font, 16)
	bar:SetDurationFont(v.media.font, 16)

	--Make sure only the CD monitor gets the caster and spell names
	if group == SN.F.debuffs then
		bar:SetLabel(spell)
	else
		bar:SetLabel(caster.."       "..spell)
	end

	--Add some things the bar should do on the events
	bar:SetScript("OnEvent", function(self, event, ...)
		if event == "COMBAT_LOG_EVENT_UNFILTERED" then
			local _, type, _, _, sourceName, _, _, destGUID, destname, _, _ = ...
			local spellId, spellName, spellSchool = select(12, ...)

			--Kill the bar if the debuff target is dead
			if type == "UNIT_DIED" then
				if destGUID == self:GetData("SN:arg3") then
					self:Stop()
				end
			end

			--See if the hunter Spell Readiness was cast and then kill the CD's reset bars
			--TODO: Make this more class nuetral and allow for other classes to check this
			if type == "SPELL_CAST_SUCCESS" then
				if select(2, UnitClass("player")) == "HUNTER" then
					if spellId == 23989 then
						local cdtmp = self:GetData("SN:arg2")
						if cdtmp.reset then
							self:Stop()
						end
					end
				end
			end
		end	
	end)
	--Add bar to the appropriate group
	group:Add(bar)
	bar:Start()
	--Some we can check on our combat changes
	bar:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
	
end

function SN:AnnounceCD(cooldown, caster)
	
	--Is the announce setting and in a raid and are you the leader...otherwise no spam for you
	if (SN.db.profile.CD.castannounce) and (SN.db.profile.CD.raid) and (UnitIsGroupLeader("player")) then
		
		local dur = cooldown.CD / 60
		local class, classFileName, classID = UnitClass(caster)
		
		if GetNumGroupMembers() > 1 and IsInRaid() then
			SendChatMessage(caster.." casts "..GetSpellLink(cooldown.id).." "..dur.."min".." CD", "RAID")
		elseif GetNumGroupMembers() > 1 and not IsInRaid() then
			SendChatMessage(caster.." casts "..GetSpellLink(cooldown.id).." "..dur.."min".." CD", "PARTY")
		end
	end
end