﻿-- Config UI

local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceDB = LibStub("AceDB-3.0")
local AceDBOptions = LibStub("AceDBOptions-3.0")

local selectedSpell
local cdtoggle = {}

function SN:SetupOptions()
	SN.options.args.profile = AceDBOptions:GetOptionsTable(SN.db)
	AceConfig:RegisterOptionsTable("SN", SN.options, nil)
	
	SN.optionsFrames = {}
	SN.optionsFrames.general = AceConfigDialog:AddToBlizOptions("SN", "Serenity Now", nil, "general")
	
end

SN.TexCoords = {.08, .92, .08, .92}

local function SpellName(id)
	local name, _, _, _, _, _, _, _, _ = GetSpellInfo(id) 	
	if not name then
		return 'Null'
	else
		return name
	end
end

SN.V.defaults = {
	profile = {
		["CD"] = {
			castannounce = true,
			show = "always",
			raid = true,
		},
		["Frames"] = {
			lock = true,
		},
		["powerbar"] = {
			enable = false,
			["hunter"] = {
				{	--Beast Mastery
					{ true, "Kill Command", true, false, {1,1,1,1}, 0 },
					{ false, "Glaive Toss", true, false, {1,1,1,1}, 0 },
				},
				{	--Marksman
					{ true, "Chimera Shot", true, false, {1,1,1,1}, 0 },
					{ false, "Aimed Shot", true, false, {1,1,1,1}, 0 },
				},
				{	--Survival
					{ true, "Explosive Shot", true, false, {1,1,1,1}, 0 },
					{ false, "Black Arrow", true, false, {1,1,1,1}, 0 },
				},
			},
			["rogue"] = {
				{	--Assassination
					{ true, "Mutilate", true, false, {1,1,1,1}, 0 },
					{ false, "Dispatch", true, false, {1,1,1,1}, 0 },
				},
				{	--Combat
					{ true, "Sinister Strike", true, false, {1,1,1,1}, 0 },
					{ true, "Eviscerate", true, false, {1,1,1,1}, 0 },
				},
				{	--Subtlety
					{ true, "Backstab", true, false, {1,1,1,1}, 0 },
					{ false, "Eviscerate", true, false, {1,1,1,1}, 0 },
				},
			},
			["druid"] = {
				{	--Feral
					{ true, "Shred", true, false, {1,1,1,1}, 0 },
					{ false, "Mangle", true, false, {1,1,1,1}, 0 },
				},
				{	--Guardian
					{ true, "Savage Defense", true, false, {1,1,1,1}, 0 },
					{ false, "Frenzied Regeneration", true, false, {1,1,1,1}, 0 },
				},
			},
			["warrior"] = {
				{	--Arms
					{ true, "Slam", true, false, {1,1,1,1}, 0 },
					{ false, "Execute", true, false, {1,1,1,1}, 0 },
				},
				{	--Fury
					{ true, "Heroic Strike", true, false, {1,1,1,1}, 0 },
					{ false, "Execute", true, false, {1,1,1,1}, 0 },
				},
				{	--Prot
					{ true, "Shield Block", true, false, {1,1,1,1}, 0 },
					{ false, "Shield Barrier", true, false, {1,1,1,1}, 0 },
				},
			},
		},
	},
}

SN.options =  {
	type = "group",
	name = "Serenity Now".." "..SN.ver,
	args = {
		general = {
			type = "group",
			name = "general",
			args = {
				descrip = {
					order = 0,
					type = "description",
					name = "A tool to have as much of the needed information from each class\nwithin eye sight so that you can say Serenity Now!",
				},
				h1 = {
                    order = 1,
                    type = "header",
                    name = "",
                },
				castannounce = {
					type = "toggle",
					name = "Announce Casts",
					order = 2,
					get = function()
						return SN.V.defaults.profile.CD.castannounce
					end,
					set = function(key, value)
						SN.V.defaults.profile.CD.castannounce = value
					end,
				},		
				lock = {
					order = 3,
					name = "Lock Frames",
					type = 'toggle',
					get = function()
						return SN.db.profile.Frames.lock 
					end,
					set = function(key, value)
						SN.db.profile.Frames.lock = value
						SN:MoveFrames(value)
					end,
				},
				raid = {
					order = 4,
					name = "Raid Only CDs",
					desc = "Shows the raid wide cooldowns instead of personal cooldowns. Must be the group leader for this feature to work.",
					type = "toggle",
					get = function()
						return SN.db.profile.CD.raid
					end,
					set = function(key, value)
						SN.db.profile.CD.raid = value
					end,
				},
				powertick = {
					order = 5,
					name = "Powebar Ticks",
					desc = "Tick marks on the powerbar to represent how much power you need to cast your main spell.",
					type = "toggle",
					get = function()
						return SN.db.profile.powerbar.enable
					end,
					set = function(key, value)
						SN.db.profile.powerbar.enable = value
						SN:PowebarTicks()
					end,
				},
				h2 = {
                    order = 6,
                    type = "header",
                    name = "",
                },
				cooldowns = {
					order = 24,
					type = "group",
					name = "Cooldowns",
					args = {
						selectSpell = {
							name = "Select Spell",
							type = "select",
							order = 0,						
							values = function()
								local values = {}
								for _, spell in pairs(SN.db.profile.cooldowns) do
									local name = GetSpellInfo(spell.id)
									values[spell.id] = name
								end
								return values
							end,
							get = function(info) return selectedSpell end,
							set = function(info, value)
								selectedSpell = value
							end,
						},
						editSpell = {	
							name = "Enabled",
							type = 'toggle',
							order = 1,
							get = function(info) 
								for _, spell in pairs(SN.db.profile.cooldowns) do
									if selectedSpell == spell.id then
										return spell.enable
									end
								end
							end,
							set = function(info, value) 
								for _, spell in pairs(SN.db.profile.cooldowns) do
									if selectedSpell == spell.id then
										spell.enable = value
									end
								end
							end,
						},
					},
				},
				debuffs = {
					order = 25,
					type = "group",
					name = "Debuffs",
					args = {
						selectSpell = {
							name = "Select Spell",
							type = "select",
							order = 0,						
							values = function()
								local values = {}
								for _, spell in pairs(SN.db.profile.debuffs) do
									local name = GetSpellInfo(spell.id)
									values[spell.id] = name
								end
								return values
							end,
							get = function(info) return selectedSpell end,
							set = function(info, value)
								selectedSpell = value
							end,
						},
						editSpell = {	
							name = "Enabled",
							type = 'toggle',
							order = 1,
							get = function(info) 
								for _, spell in pairs(SN.db.profile.debuffs) do
									if selectedSpell == spell.id then
										return spell.enable
									end
								end
							end,
							set = function(info, value) 
								for _, spell in pairs(SN.db.profile.debuffs) do
									if selectedSpell == spell.id then
										spell.enable = value
									end
								end
							end,
						},
					},
				},
			},
		},
	}
}